tvPsi: Time-Varying Coefficient Arrays of the Orthogonalised MA...

tvPsiR Documentation

Time-Varying Coefficient Arrays of the Orthogonalised MA Represention

Description

Returns the estimated orthogonalised time-varying coefficient arrays of the moving average representation of a stable tvvar object obtained with function tvVAR.

Usage

tvPsi(
  x,
  nstep = 10,
  ortho.cov = "const",
  bw.cov = NULL,
  unit.shock = FALSE,
  ...
)

Arguments

x

An object of class tvvar, generated by tvVAR().

nstep

An integer specifying the number of othogonalised moving error coefficient matrices to be calculated for each time t.

ortho.cov

A character either 'const' if the error cov matrix must be estimated by a constant or 'tv' if it is estimated as a time-varying matrix. Default is 'const'.

bw.cov

A scalar (optional) with the bandwidth to estimate the errors variance-covariance matrix.

unit.shock

Logical. If TRUE, the impulse responses are calculated for a one unit shock. If FALSE (default), they are calculated for a one standard deviation shock.

...

Other parameters passed to specific methods.

Value

A list with an array of dimensions (obs x neq x neq nstep + 1) holding the estimated time varying coefficients of the moving average representation, and the bandwidth used to estimate the covariance matrix (optional).


tvReg documentation built on March 12, 2026, 5:06 p.m.